@@ -353,7 +353,7 @@ class Api :
         #TDEVICE_API int TDeviceAdcGetCurrent(void* hdl, int dutIdx, int groupIdx, int chIdx);
         this.TDeviceAdcGetCurrent = Load_DLL['TDeviceAdcGetCurrent']
         this.TDeviceAdcGetCurrent.restype=c_int;
-        this.TDeviceAdcGetCurrent.argtypes=[c_void_p, c_int, c_int, c_char_p]
+        this.TDeviceAdcGetCurrent.argtypes=[c_void_p, c_int, c_int, c_int]
         
         #TDEVICE_API int TDeviceAdcGetCurrentByPsID(void* hdl, int dutIdx, int psID);
         this.TDeviceAdcGetCurrentByPsID = Load_DLL['TDeviceAdcGetCurrentByPsID']
