@@ -7,6 +7,13 @@ if platform.system()=="Windows" :
 else :
     from Anapass.TDeviceAndroid import *
 
+##############################################################################################################################
+#
+# class TDevice
+#
+##############################################################################################################################
+
+
 class TDevice :
 
     class Type(enum.IntEnum) : 
@@ -523,4 +530,23 @@ class TDevice :
 
 
 
+##############################################################################################################################
+#
+# class TDatabase
+#
+##############################################################################################################################
 
+class TDatabase :
+
+    def __init__(this): 
+
+        if platform.system()=="Windows" : 
+            print("os is windows")
+            this.__TDevice = TDeviceWin(deviceType.value)
+        else :
+            this.__TDevice = TDeviceAndroid(deviceType.value)
+
+        this.__DeviceType = deviceType
+
+        #Staticts
+        this.__AgingMeasureAdcCount = 0
